@@ -1,3 +1,9 @@
+"""
+.. testsetup::
+
+    from compas.geometry import Vector
+
+"""
 from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
@@ -45,6 +51,7 @@ class Vector(Primitive):
 
     Examples
     --------
+
     >>> u = Vector(1, 0, 0)
     >>> v = Vector(0, 1, 0)
     >>> u
@@ -67,6 +74,7 @@ class Vector(Primitive):
     0.0
     >>> u.cross(v)
     Vector(0.000, 0.000, 1.000)
+
     """
 
     __slots__ = ['_x', '_y', '_z']
@@ -80,6 +88,26 @@ class Vector(Primitive):
         self.y = y
         self.z = z
 
+    @property
+    def DATASCHEMA(self):
+        from schema import Schema
+        from compas.data import is_float3
+        return Schema(is_float3)
+
+    @property
+    def JSONSCHEMA(self):
+        from compas import versionstring
+        schema = {
+            "$schema": "http://json-schema.org/draft-07/schema#",
+            "$id": "https://github.com/compas-dev/compas/schemas/vector.json",
+            "$compas": versionstring,
+            "type": "array",
+            "minItems": 3,
+            "maxItems": 3,
+            "items": {"type": "number"}
+        }
+        return schema
+
     @property
     def data(self):
         """dict : The data dictionary that represents the vector."""
@@ -255,6 +283,9 @@ class Vector(Primitive):
         """
         return Vector(self.x ** n, self.y ** n, self.z ** n)
 
+    def __neg__(self):
+        return self.scaled(-1.0)
+
     def __iadd__(self, other):
         """Add the components of the other vector to this vector.
 
@@ -432,7 +463,8 @@ class Vector(Primitive):
 
         Examples
         --------
-        >>> R = Rotation.from_axis_and_angle(Vector.Zaxis(), radians(90))
+        >>> from compas.geometry import Rotation
+        >>> R = Rotation.from_axis_and_angle(Vector.Zaxis(), math.radians(90))
         >>> u = Vector(1.0, 0.0, 0.0)
         >>> vectors = [u]
         >>> Vector.transform_collection(vectors, R)
@@ -464,7 +496,8 @@ class Vector(Primitive):
 
         Examples
         --------
-        >>> R = Rotation.from_axis_and_angle(Vector.Zaxis(), radians(90))
+        >>> from compas.geometry import Rotation
+        >>> R = Rotation.from_axis_and_angle(Vector.Zaxis(), math.radians(90))
         >>> u = Vector(1.0, 0.0, 0.0)
         >>> vectors = [u]
         >>> vectors = Vector.transformed_collection(vectors, R)
@@ -676,6 +709,41 @@ class Vector(Primitive):
         v.unitize()
         return v
 
+    def invert(self):
+        """Invert the direction of this vector
+
+        Note
+        ____
+        a negation of a vector is similar to inverting a vector
+
+        Examples
+        --------
+        >>> u = Vector(1.0, 0.0, 0.0)
+        >>> v = u.copy()
+        >>> u.invert()
+        >>> u == v
+        False
+        >>> u.invert()
+        >>> u == v
+        True
+        >>> v == --v
+        True
+        """
+        self.scale(-1.)
+
+    def inverted(self):
+        """Returns a inverted copy of this vector
+
+        Examples
+        --------
+        >>> u = Vector(1.0, 0.0, 0.0)
+        >>> v = u.inverted()
+        >>> w = u + v
+        >>> w.length
+        0.0
+        """
+        return self.scaled(-1.)
+
     def scale(self, n):
         """Scale this vector by a factor n.
 
@@ -780,10 +848,9 @@ class Vector(Primitive):
 
         Examples
         --------
-        >>> from math import pi
         >>> u = Vector(1.0, 0.0, 0.0)
         >>> v = Vector(0.0, 1.0, 0.0)
-        >>> u.angle(v) == 0.5 * pi
+        >>> u.angle(v) == 0.5 * math.pi
         True
         """
         return angle_vectors(self, other)
@@ -805,12 +872,11 @@ class Vector(Primitive):
 
         Examples
         --------
-        >>> from math import pi
         >>> u = Vector(1.0, 0.0, 0.0)
         >>> v = Vector(0.0, 1.0, 0.0)
-        >>> u.angle_signed(v, Vector(0.0, 0.0, 1.0)) == 0.5 * pi
+        >>> u.angle_signed(v, Vector(0.0, 0.0, 1.0)) == 0.5 * math.pi
         True
-        >>> u.angle_signed(v, Vector(0.0, 0.0, -1.0)) == -0.5 * pi
+        >>> u.angle_signed(v, Vector(0.0, 0.0, -1.0)) == -0.5 * math.pi
         True
         """
         return angle_vectors_signed(self, other, normal)
@@ -830,10 +896,9 @@ class Vector(Primitive):
 
         Examples
         --------
-        >>> from math import pi
         >>> u = Vector(1.0, 0.0, 0.0)
         >>> v = Vector(0.0, 1.0, 0.0)
-        >>> u.angles(v)[0] == 0.5 * pi
+        >>> u.angles(v)[0] == 0.5 * math.pi
         True
         """
         return angles_vectors(self, other)
@@ -848,10 +913,9 @@ class Vector(Primitive):
 
         Examples
         --------
-        >>> from math import radians
         >>> from compas.geometry import Rotation
         >>> u = Vector(1.0, 0.0, 0.0)
-        >>> R = Rotation.from_axis_and_angle([0.0, 0.0, 1.0], radians(90))
+        >>> R = Rotation.from_axis_and_angle([0.0, 0.0, 1.0], math.radians(90))
         >>> u.transform(R)
         >>> u
         Vector(0.000, 1.000, 0.000)
@@ -876,10 +940,9 @@ class Vector(Primitive):
 
         Examples
         --------
-        >>> from math import radians
         >>> from compas.geometry import Rotation
         >>> u = Vector(1.0, 0.0, 0.0)
-        >>> R = Rotation.from_axis_and_angle([0.0, 0.0, 1.0], radians(90))
+        >>> R = Rotation.from_axis_and_angle([0.0, 0.0, 1.0], math.radians(90))
         >>> v = u.transformed(R)
         >>> v
         Vector(0.000, 1.000, 0.000)
@@ -887,17 +950,3 @@ class Vector(Primitive):
         vector = self.copy()
         vector.transform(T)
         return vector
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == '__main__':
-
-    import doctest
-
-    from math import radians  # noqa F401
-    from compas.geometry import Rotation  # noqa F401
-
-    doctest.testmod(globs=globals())
