@@ -333,11 +333,3 @@ class GeometryPlotter:
 
         """
         plt.savefig(filepath, **kwargs)
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == "__main__":
-    pass
